Learn R Programming

SIAtools (version 0.1.4)

print.sm_manifest: Print a SIA Modules Manifest

Description

Prints out the SIA Modules Manifest obtained through get_modules(). By default, a plain YAML content is returned, but you can also get a formatted output in a tibble, which is suitable for packages with large number of SIA modules.

Usage

# S3 method for sm_manifest
print(x, ..., as_tibble = FALSE)

Value

Called for side effects by default. Returns a tibble if as_tibble

argument is set to TRUE.

Arguments

x

sm_manifest object, i.e., an output of get_modules().

...

Not used at the moment.

as_tibble

logical, print the manifest as a tibble? Defaults to FALSE.

See Also

Other helpers: curr_proj(), default_shiny_io_functions, edit_rstudio_shortcuts(), list_categories(), open_sm_manifest(), sia_head_tag()