Prints out the SIA Modules Manifest obtained through get_modules(). By
default, a plain YAML content is returned, but you can also get a formatted
output in a tibble, which is suitable for packages with large number of SIA
modules.
# S3 method for sm_manifest
print(x, ..., as_tibble = FALSE)Called for side effects by default. Returns a tibble if as_tibble
argument is set to TRUE.
sm_manifest object, i.e., an output of get_modules().
Not used at the moment.
logical, print the manifest as a tibble? Defaults to
FALSE.
Other helpers:
curr_proj(),
default_shiny_io_functions,
edit_rstudio_shortcuts(),
list_categories(),
open_sm_manifest(),
sia_head_tag()